@@ -1,10 +1,12 @@
+#pylint: disable-all
 from kaylee.testsuite import  PROJECTS_DIR
 
 
-WORKER_SCRIPT = '/static/js/kaylee/klworker.js'
+WORKER_SCRIPT_URL = '/static/js/kaylee/klworker.js'
 
 PROJECTS_DIR = PROJECTS_DIR
 
+SECRET_KEY = 'aJD2fn;1340913)*(!!&$)(#&<AHFB12b'
 
 REGISTRY = {
     'name' : 'MemoryNodesRegistry',
@@ -22,10 +24,10 @@ APPLICATIONS = [
       'controller' : {
             'name' :'DummyController',
             'config' : {},
-            'storage' : {
+            'temporal_storage' : {
                 'name' : 'MemoryTemporalStorage',
                 },
-            'app_storage' : {
+            'permanent_storage' : {
                 'name' : 'MemoryPermanentStorage',
                 },
             },
